@@ -83,8 +83,7 @@ HdrWizardForm::HdrWizardForm(QWidget *p) : QDialog(p), hdrCreationManager(NULL),
 	SLOT(loadRespCurveFilename(const QString&)));
 	connect(loadImagesButton,SIGNAL(clicked()),this,SLOT(loadImagesButtonClicked()));
 
-	QtpfsguiOptions *opts=QtpfsguiOptions::getInstance();
-	hdrCreationManager = new HdrCreationManager ( opts->num_threads, opts->tempfilespath, opts->dcraw_options );
+	hdrCreationManager = new HdrCreationManager();
 	connect(hdrCreationManager, SIGNAL(fileLoaded(int,QString,float)), this, SLOT(fileLoaded(int,QString,float)));
 	connect(hdrCreationManager,SIGNAL(finishedLoadingInputFiles(QStringList)),this, SLOT(finishedLoadingInputFiles(QStringList)));
 	connect(hdrCreationManager,SIGNAL(errorWhileLoading(QString)),this, SLOT(errorWhileLoading(QString)));
@@ -270,7 +269,7 @@ void HdrWizardForm::loadRespCurveFromFileCheckboxToggled( bool checkedfile ) {
     if (checkedfile && loadcurvefilename != "") {
 	//update chosen config
 	hdrCreationManager->chosen_config.response_curve=FROM_FILE;
-	hdrCreationManager->chosen_config.LoadCurveFromFilename=loadcurvefilename;
+	hdrCreationManager->chosen_config.LoadCurveFromFilename=strdup(QFile::encodeName(loadcurvefilename).constData());
 	//and ENABLE nextbutton
 	NextFinishButton->setEnabled(TRUE);
     }
@@ -293,7 +292,7 @@ void HdrWizardForm::loadRespCurveFromFileCheckboxToggled( bool checkedfile ) {
 void HdrWizardForm::saveRespCurveToFileCheckboxToggled( bool checkedfile ) {
 	//if checkbox is checked AND we have a valid filename
 	if (checkedfile && savecurvefilename != "") {
-		hdrCreationManager->chosen_config.SaveCurveToFilename=savecurvefilename;
+		hdrCreationManager->chosen_config.SaveCurveToFilename=strdup(QFile::encodeName(savecurvefilename).constData());
 		NextFinishButton->setEnabled(TRUE);
 	}
 	//if checkbox is checked AND no valid filename
@@ -430,7 +429,7 @@ void HdrWizardForm::modelComboBoxActivated(int from_gui) {
 void HdrWizardForm::loadRespCurveFilename( const QString & filename_from_gui) {
 	if (!filename_from_gui.isEmpty()) {
 		hdrCreationManager->chosen_config.response_curve=FROM_FILE;
-		hdrCreationManager->chosen_config.LoadCurveFromFilename=filename_from_gui;
+		hdrCreationManager->chosen_config.LoadCurveFromFilename=strdup(QFile::encodeName(filename_from_gui).constData());
 	}
 }
 
